1.1.1.2.1.1.1.2. nikola.plugins.command.rst2html package — Nikola 8.1.3 documentation

# 1.1.1.2.1.1.1.2. nikola.plugins.command.rst2html package

Compile reStructuredText to HTML, using Nikola architecture.

class nikola.plugins.command.rst2html.CommandRst2Html(*args, **kwargs)

  Bases: :class:`nikola.plugin_categories.Command`

  Compile reStructuredText to HTML, using Nikola architecture.

  doc_purpose = 'compile reStructuredText to HTML files'
  doc_usage = 'infile'
  name = 'rst2html'
  needs_config = False